Trait FromRef
trait FromRef<T>
Used to do reference-to-value conversions thus not consuming the input value.
This is mainly used with State to extract "substates" from a reference to main application
state.
See State for more details on how library authors should use this trait.
This trait can be derived using #[derive(FromRef)].
Required Methods
fn from_ref(input: &T) -> SelfConverts to this type from a reference to the input type.
Implementors
impl<T> FromRef for AppendHeaders<I>impl<T> FromRef for DefaultBodyLimitimpl<T> FromRef for T